# ISO 6346 Freight Containers: Coding, Identification and Marking

[API Documentation](https://iso6346-containers.readthedocs.io/en/latest/)

## Synopsis

CSC owner codes.

The calculation is based upon:

 * [ISO 6346:2022 Freight containers — Coding, identification and marking](https://www.iso.org/standard/83558.html)

## Installation

See the PyPI package [`iso6346-containers`](https://pypi.org/project/iso6346-containers/):

```
pip install iso6346-containers
```

## Author

2024 Damien Bezborodov
